==> jc-1.4.0.tar.gz: org/dellroad/jc/BootstrapObjectGenerator.h <==
// public class org.dellroad.jc.BootstrapObjectGenerator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96618ec35b7dd7e8 org_dellroad_jc_BootstrapObjectGenerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_org_dellroad_jc_ObjectGenerator$object;
struct _jc_org_dellroad_jc_SearchpathFinder$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object	_jc_org_dellroad_jc_BootstrapObjectGenerator$object;

typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct	_jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct {
	struct _jc_java_lang_Class$object	*class__24org__24dellroad__24jc__24BootstrapObjectGenerator;
};
extern _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct _jc_org_dellroad_jc_BootstrapObjectGenerator$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$_init$a0dc5ae75b002d26(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, jboolean, jboolean);

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$generate$51855fe6b2410df8(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$generateMatches$056c7626c205e559(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$generate$51855fe6b2410df8;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$generateMatches$056c7626c205e559;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_dellroad_jc_BootstrapObjectGenerator$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$doMain$2a1ebd6aaf714ad9(_jc_env *, struct _jc_object_array *);
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods {
	void	(*generate$51855fe6b2410df8)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *);
	void	(*generateMatches$056c7626c205e559)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *);
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods	org_dellroad_jc_BootstrapObjectGenerator;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs {
	struct _jc_object	*generator;
	_jc_object_array	*matchers;
	struct _jc_org_dellroad_jc_SearchpathFinder$object	*finder;
	struct _jc_java_util_HashSet$object	*generated;
	struct _jc_java_io_File$object	*objectDir;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs	org_dellroad_jc_BootstrapObjectGenerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs {
	jboolean	verbose;
	jboolean	force;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/BootstrapObjectGenerator.h <==
// public class org.dellroad.jc.BootstrapObjectGenerator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96618ec35b7dd7e8 org_dellroad_jc_BootstrapObjectGenerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_org_dellroad_jc_ObjectGenerator$object;
struct _jc_org_dellroad_jc_SearchpathFinder$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object	_jc_org_dellroad_jc_BootstrapObjectGenerator$object;

typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct	_jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct {
	struct _jc_java_lang_Class$object	*class__24org__24dellroad__24jc__24BootstrapObjectGenerator;
};
extern _jc_org_dellroad_jc_BootstrapObjectGenerator$fields_struct _jc_org_dellroad_jc_BootstrapObjectGenerator$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$_init$a0dc5ae75b002d26(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$generate$51855fe6b2410df8(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$generateMatches$056c7626c205e559(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$generate$51855fe6b2410df8;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$generateMatches$056c7626c205e559;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_dellroad_jc_BootstrapObjectGenerator$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$doMain$2a1ebd6aaf714ad9(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods {
	void	(*generate$51855fe6b2410df8)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*generateMatches$056c7626c205e559)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vmethods	org_dellroad_jc_BootstrapObjectGenerator;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs {
	struct _jc_object	*generator;
	_jc_object_array	*matchers;
	struct _jc_org_dellroad_jc_SearchpathFinder$object	*finder;
	struct _jc_java_util_HashSet$object	*generated;
	struct _jc_java_io_File$object	*objectDir;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_refs	org_dellroad_jc_BootstrapObjectGenerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs {
	jboolean	verbose;
	jboolean	force;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator_H_ */
